# ReleaseProgressionResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**release** | [**ReleaseResource**](ReleaseResource.md) |  | [optional] 
**channel** | [**ChannelResource**](ChannelResource.md) |  | [optional] 
**deployments** | **dict(str, list[DashboardItemResource])** |  | [optional] 
**next_deployments** | **list[str]** |  | [optional] 
**has_unresolved_defect** | **bool** |  | [optional] 
**release_retention_period** | [**RetentionPeriod**](RetentionPeriod.md) |  | [optional] 
**tentacle_retention_period** | [**RetentionPeriod**](RetentionPeriod.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


